[![Build Status](https://travis-ci.org/ki-tools/sls-tools-py.svg?branch=master)](https://travis-ci.org/ki-tools/sls-tools-py)
[![Coverage Status](https://coveralls.io/repos/github/ki-tools/sls-tools-py/badge.svg?branch=master)](https://coveralls.io/github/ki-tools/sls-tools-py?branch=master)

# sls-tools-py

Utilities for developing AWS Lambda functions in Python.

## Installation

`pip install sls-tools`

## Development Setup

```bash
git clone https://github.com/ki-tools/sls-tools-py.git
cd sls-tools-py
pipenv --three
source .venv/bin/activate
make pip_install
make test
```

## Module Documentation

See full module documentation [here](https://ki-tools.github.io/sls-tools-py).
